@@ -319,7 +319,9 @@ void KConfigIniBackend::writeEntries(const QByteArray &locale, QIODevice &file,
                 end = currentGroup.indexOf(QLatin1Char('\x1d'), start);
                 if (end < 0) {
                     int cgl = currentGroup.length();
-                    if (currentGroup.at(start) == QLatin1Char('$') && cgl - start <= 10) {
+                    // Start has to be smaller than currentGroup length, or otherwise currentGroup.at()
+                    // will assert: https://doc.qt.io/qt-6/qstring.html#at
+                    if (cgl > start && cgl - start <= 10 && currentGroup.at(start) == QLatin1Char('$')) {
                         for (int i = start + 1; i < cgl; i++) {
                             const QChar c = currentGroup.at(i);
                             if (c < QLatin1Char('a') || c > QLatin1Char('z')) {
@@ -515,29 +517,15 @@ bool KConfigIniBackend::writeConfig(const QByteArray &locale, KEntryMap &entryMa
             return false;
         }
     } else {
-        // Open existing file. *DON'T* create it if it suddenly does not exist!
-#if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
-        int fd = QT_OPEN(QFile::encodeName(filePath()).constData(), O_WRONLY | O_TRUNC);
-        if (fd < 0) {
-            return false;
-        }
-        QFile f;
-        if (!f.open(fd, QIODevice::WriteOnly)) {
-            QT_CLOSE(fd);
-            return false;
-        }
-        writeEntries(locale, f, writeMap);
-        f.close();
-        QT_CLOSE(fd);
-#else
         QFile f(filePath());
-        // XXX This is broken - it DOES create the file if it is suddenly gone.
-        if (!f.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+
+        // Open existing file. *DON'T* create it if it suddenly does not exist!
+        if (!f.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::ExistingOnly)) {
             return false;
         }
+
         f.setTextModeEnabled(true);
         writeEntries(locale, f, writeMap);
-#endif
     }
     return true;
 }
